<?php
# *********************** LICENSE *****************************************************	#
#	This file is part of EoleCAS plugin.
#
#	Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
#	Licence CeCill  cf /root/LicenceEole.txt
#	eole@ac-dijon.fr
# *************************************************************************************	#

/************************************************
 *   EoleCAS plugin file		                *
 *   Extension of CAS plugin file               *
 *   from Jean-francois Rey                     *
 *   jean-francois.rey@univ-avignon.fr          *
 *   file: plugin_eolecas.php			        *
 *   version: 2.00                           	*
 *   date: 07/11/07                          	*
 *   author : Gaston TJEBBES               	    *
 *   email: g.tjebbes@ac-dijon.fr              	*
 ************************************************/

/*
 * name: plugin EOLECAS
 * description: Plugin CAS pour Envole (plugin EOLE). Attention !! Ce plugin n'est pas désactivable.
 * display:  style="font-weight:bolder;"
 * dependencies: no
 * author: Gaston TJEBBES
 * url: http://eole.orion.education.fr
 */
define("CAS_NAME","plugin EOLECAS");

// Librairies et fichiers de configuration CAS
include_once("configCAS/cas.inc.php");
include_once("cas.inc.php");
include_once('CAS/eoleCAS.php');

// Fonction utiles
include_once("plugcas_tools.php");

if (__CAS_DEBUG){
    EolephpCAS::setDebug("/var/log/posh/eolecas.log");
}

// portal/index.php
register_hook("index_php", "plugcas_userindex",1,1);

// index.php admin et portal
register_hook("userinterface_header","plugcas_userinterface_header",1,1);
register_hook("admininterface_header","plugcas_userinterface_header",1,1);

// portal/login.php
register_hook("login_php","loginPageHook",1,1);
// logout function
register_hook("logout","eoleLogoutHook");
// init session
register_hook("scr_connect_session_initialized", "addAvatarInSession", 1,1);

function plugcas_userindex(){
    /*
     * Hook à l'initialisation de la page d'index 'utilisateur'
     */
    if( __defaultAuthen=="cas"){
        // Going to Cas login page if not done
        if(__defaultmode=="connected" && !isset($_REQUEST['ticket']) ){
            header("location:" . login_link());
            exit();
        }
    }
}
function addAvatarInSession($user){
    /*
     * Ajoute les informations eole dans l'objet user de la session
     * $user: objet utilisateur créé dans la fonction user_login_form (cf en bas)
     */
    $_SESSION['avatar'] = $user;
}
function buildAvatar(){
    /*
     * Construit l'avatar eole
     */

    echo "<script type='text/javascript'>";
    foreach ($_SESSION['avatar'] as $key=>$value){
        echo "$" . "p.app.user.set('" . $key . "', '" . $value . "');";
    }
    echo "</script>";
}
function plugcas_userinterface_header($page)
{
    /*
     * Envoyé à chaque initialisation de page (admininterface également)
     */
    echo "<link type='image/xicon' href='../images/eole_icone.ico' rel='shortcut icon' />";
    if( __defaultAuthen=="cas"){
        if ( __CAS_LOGOUT == false){
            setLogoutHook(); // Ajout d'un hook javascript pour le logout centralisé
        }
        setAvatarLibHook();

        if (($page == "portal/login.php" || $page == "admin/login.php") && !isset($_REQUEST['ticket']) ){
            setLoginRedirectHook();
        }elseif ( $page != "portal/login.php" && $page !="admin/login.php"){
            buildAvatar();
        }
        setChangeUserHook();
    }
}
/************************* login.php */
// HEADER
function loginPageHook(){
    /*
     * Lance la vérification cas avant d'afficher la page de login
     * Permet au client CAS de renvoyer une page d'erreur en cas de ticket invalide
     * Cache le formulaire d'authentification de l'appli et le rempli pour passer à l'étape suivante
     * (il faut le laisser (pas le vider) : on ne coupe pas la branche sur laquelle on est assis)
     * Initialise la session de l'utilisateur
     */
    initCasProxy();
    eolephpcas::checkAuthentication();
    if (! isset($_REQUEST['ticket']) || $_REQUEST['ticket'] == ""){
        header("location:/posh/portal/index.php");
        exit();
    }
    $user = EolephpCAS::getUser();
    echo "<script type='text/javascript'>";
    echo "var fcas = new Array();";
    echo "fcas.password = new Array();";
    echo "fcas.password.value=".random_number().";";
    echo "fcas.username = new Array();";
    echo "fcas.username.value='".$user."';";
    echo "function cacheForm(){" . "$" . "('loginbox').style.display = 'none';";
    echo "$"."p.app.connection.set(fcas,$"."p.app.pages.isPageExisting);";
    echo "}";
    echo "window.onload = cacheForm;";
    echo "</script>";
}
//**************************************
if ( __defaultAuthen=="cas" && !function_exists('user_login_form') ):
    /*
     * On redéfinit la fonction de vérification de login, on est déjà authentifié
     * Donc on renvoie true et on construit l'objet $user qui sera utilisé plus tard
     */
    function user_login_form($username,$password,&$user,&$errormsg)
    {
        global $DB,$authentif_getUserByName;
        initCasProxy();
        launch_hook('user_login_form',$username,$password);
        // On récupère le user dans la base
        $DB->getResults($authentif_getUserByName,$DB->quote($username));
        if ($DB->nbResults()<=0)
        {
            $errormsg.=lg("incorrectLogin");
        }else{
            $row=$DB->fetch(0);
            if ($row["typ"]=="N" OR $row["typ"]=="M"){
                $errormsg.=lg("userNotValidated");
            }else{
                if(EolephpCAS::isAuthenticated()){
                    // ok go to user page
                    $username = EolephpCAS::getUser();
                }else{
                    $errormsg.=lg("incorrectLogin");
                }
            }
            if( $errormsg == "" ){
                /*
                 * Récupération des infos utilisateurs
                 */
                $user_details = EolephpCAS::getDetails();
                $rne = $user_details['infos']['rne'][0];
                $group = "";
                $groups = $user_details['infos']['user_groups'];
                for ($i=0;$i<count($groups);$i++){
                    switch ( $groups[$i] ){
                        case "eleves" :
                            $group =  $groups[$i];
                            break;
                        case "professeurs" :
                            $group =  $groups[$i];
                            break;
                        case "domainadmins" :
                            $group =  $groups[$i];
                            break;
                        case "responsables" :
                            $group =  $groups[$i];
                            break;
                        case "administratifs" :
                            $group =  $groups[$i];
                            break;
                    }
                }
                $pass = md5($password);
                $uid = $row["id"];

                $user->id = $uid;
                $user->username = $username;
                $user->type = $row["typ"];
                $user->pass = $pass;
                $user->lang = $row["lang"];
                $user->longname = $row["long_name"] == "" ? $username:$row["long_name"];
                $user->picture = $row['picture'];

                /*
                 * Rajout des informations qui seront utilisées pour piwik
                 */
                $user->userId = $uid;
                $user->rne = $rne;
                $user->group = $group;
                $user->password = $pass;

                $DB->freeResults();
                $DB->execute($authentication_updateConnectDate,$user->id);
                return true;
            }
        }
        $DB->freeResults();
        return false;
    }
endif;
function eoleLogoutHook(){
    /*
     * Fonction de logout
     */
    if (__defaultAuthen=="cas"){
        if(isset($_GET["act"]) && $_GET["act"]=="logout" && $_GET["from"] != "A") { // not admin
            initCasProxy();
            // Logout effectif
            if (method_exists(phpCAS, 'logoutWithUrl')){
                EolephpCAS::logoutWithUrl(cas_return());
            }else{
                EolephpCAS::logout(cas_return());
            }
        }
    }
}
?>
